@@ -11,10 +11,10 @@ from robin_sd_upload.slack_interaction import slack_handler
 from robin_sd_upload.supportive_scripts import yaml_parser
 from robin_sd_upload.supportive_scripts import logger
 
-import robin_sd_upload.supportive_scripts.validate as validate
-import robin_sd_upload.supportive_scripts.create_zip as create_zip
-import robin_sd_upload.supportive_scripts.remove_zip as remove_zip
-import robin_sd_upload.supportive_scripts.check_upload_file as check_upload_file
+from robin_sd_upload.supportive_scripts import check_upload_file
+from robin_sd_upload.supportive_scripts import validate
+from robin_sd_upload.supportive_scripts import create_zip
+from robin_sd_upload.supportive_scripts import remove_zip
 
 def arg_parser():
     parser = argparse.ArgumentParser(
@@ -55,8 +55,8 @@ def arg_parser():
             print('Please provide all the arguments: --type, --version, --source')
             exit(1)
         # check if the radar type is valid
-        validate(radarType, version_name)
-        if check_upload_file(upload_file_path, version_name) is False:
+        validate.validate(radarType, version_name)
+        if check_upload_file.check_upload_file(upload_file_path, version_name) is False:
             exit(1)
         temp_dir = tempfile.mkdtemp()
         # version_dir_to_upload= os.path.join(upload_file_path, version_name)
@@ -65,9 +65,9 @@ def arg_parser():
         # print('version_dir_to_upload: ', version_dir_to_upload)
         # print('zipped_file_path: ', zipped_file_path)
         
-        create_zip(zipped_file_path, version_name)
+        create_zip.create_zip(zipped_file_path, version_name)
         push_software(zipped_file_path, radarType, version_name)
-        remove_zip(zipped_file_path)
+        remove_zip.remove_zip(zipped_file_path)
         logger.log(message="Software uploaded successfully.", log_level="info", to_file=True, to_terminal=True)
         exit(0)
     elif args.slack:
